# Generated by Django 4.2.13 on 2024-07-02 10:42

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
    ]

    operations = [
        migrations.CreateModel(
            name="Relation",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("subj_object_id", models.PositiveIntegerField()),
                ("obj_object_id", models.PositiveIntegerField()),
                (
                    "obj_content_type",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="relation_obj_set",
                        to="contenttypes.contenttype",
                    ),
                ),
                (
                    "subj_content_type",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="relation_subj_set",
                        to="contenttypes.contenttype",
                    ),
                ),
            ],
            bases=(models.Model,),
        ),
    ]
