# Generated by Django 5.2.2 on 2025-07-01 12:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("relations", "0002_alter_relation_obj_object_id_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="relation",
            index=models.Index(
                fields=["subj_content_type"], name="relations_r_subj_content_type"
            ),
        ),
        migrations.AddIndex(
            model_name="relation",
            index=models.Index(
                fields=["subj_object_id"], name="relations_r_subj_object_id"
            ),
        ),
        migrations.AddIndex(
            model_name="relation",
            index=models.Index(
                fields=["obj_content_type"], name="relations_r_obj_content_type"
            ),
        ),
        migrations.AddIndex(
            model_name="relation",
            index=models.Index(
                fields=["obj_object_id"], name="relations_r_obj_object_id"
            ),
        ),
        migrations.AddIndex(
            model_name="relation",
            index=models.Index(
                fields=["subj_content_type", "subj_object_id"],
                name="relations_r_subj_c_t_o_i",
            ),
        ),
        migrations.AddIndex(
            model_name="relation",
            index=models.Index(
                fields=["obj_content_type", "obj_object_id"],
                name="relations_r_obj_c_t_o_i",
            ),
        ),
    ]
