# Generated by Django 5.2.5 on 2025-08-25 05:53

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("sample_project", "0009_versionprofession"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="group",
            options={
                "ordering": ["label"],
                "verbose_name": "group",
                "verbose_name_plural": "groups",
            },
        ),
        migrations.AlterModelOptions(
            name="person",
            options={
                "ordering": ["surname", "forename"],
                "verbose_name": "person",
                "verbose_name_plural": "persons",
            },
        ),
        migrations.AlterModelOptions(
            name="place",
            options={
                "ordering": ["label"],
                "verbose_name": "place",
                "verbose_name_plural": "places",
            },
        ),
    ]
