{% load i18n %}
<a title="{% translate "collections" %}"
   href="{% url 'apis_core:collections:collectionobjectformview' record.content_type record.pk %}"
   class="object-collections"><span class="material-symbols-outlined">bookmarks</span></a>
