# Generated by Django 5.1.5 on 2025-04-17 09:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "sample_project",
            "0006_alter_group_label_alter_person_date_of_birth_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="person",
            name="forename",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="forename"
            ),
        ),
        migrations.AlterField(
            model_name="versionperson",
            name="forename",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="forename"
            ),
        ),
    ]
