# Generated by Django 5.2.4 on 2025-08-05 09:28

import django.db.models.deletion
from django.db import migrations, models

import apis_core.generic.abc


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            state_operations=[
                migrations.CreateModel(
                    name="Uri",
                    fields=[
                        (
                            "id",
                            models.AutoField(
                                auto_created=True,
                                primary_key=True,
                                serialize=False,
                                verbose_name="ID",
                            ),
                        ),
                        (
                            "uri",
                            models.URLField(
                                blank=True, max_length=255, null=True, unique=True
                            ),
                        ),
                        ("object_id", models.PositiveIntegerField(null=True)),
                        (
                            "content_type",
                            models.ForeignKey(
                                null=True,
                                on_delete=django.db.models.deletion.CASCADE,
                                to="contenttypes.contenttype",
                            ),
                        ),
                    ],
                    bases=(apis_core.generic.abc.GenericModel, models.Model),
                ),
            ],
            database_operations=[],
        )
    ]
