a #logo:hover {
    opacity: 0.5;
}

footer a:has(> img),
footer a:has(> span[class*="material-symbols"]) {
    display: inline-block;
}

footer a:has(> img):hover,
footer a:has(> span[class*="material-symbols"]):hover {
    text-decoration: none;
}

/* scroll-to-top button */
#btn-back-to-top {
    position: fixed;
    bottom: 20px;
    right: 20px;
    display: none;
    opacity: 0.5;
    background-color: var(--btn-back-to-top-bg-color, #dc3545);
    color: var(--btn-back-to-top-color, #ffffff);
}

footer .icon {
    height: 1em;
    font-size: 1.5em;
}
