{% extends "generic/generic_content.html" %}
{% load generic %}

{% block title %}
  {{ object }}
{% endblock title %}

{% if object %}

  {% block content %}
    <div class="container-fluid">
      {% template_list object prefix="partials/" suffix="_card.html" as template_list %}
      {% include template_list %}
    </div>
  {% endblock content %}

{% endif %}
