# Generated by Django 5.1.7 on 2025-03-27 08:14

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sample_project", "0005_place_feature_code_versionplace_feature_code"),
    ]

    operations = [
        migrations.AlterField(
            model_name="group",
            name="label",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="label"
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="date_of_birth",
            field=models.DateField(blank=True, null=True, verbose_name="date of birth"),
        ),
        migrations.AlterField(
            model_name="person",
            name="date_of_death",
            field=models.DateField(blank=True, null=True, verbose_name="date of death"),
        ),
        migrations.AlterField(
            model_name="person",
            name="forename",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="forname"
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="gender",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="gender"
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="surname",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="surname"
            ),
        ),
        migrations.AlterField(
            model_name="place",
            name="feature_code",
            field=models.CharField(
                blank=True,
                default="",
                help_text='<a href="https://www.geonames.org/export/codes.html">Geonames Feature Code List</a>',
                max_length=16,
                verbose_name="feature code",
            ),
        ),
        migrations.AlterField(
            model_name="place",
            name="label",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="label"
            ),
        ),
        migrations.AlterField(
            model_name="place",
            name="latitude",
            field=models.FloatField(blank=True, null=True, verbose_name="latitude"),
        ),
        migrations.AlterField(
            model_name="place",
            name="longitude",
            field=models.FloatField(blank=True, null=True, verbose_name="longitude"),
        ),
        migrations.AlterField(
            model_name="versiongroup",
            name="label",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="label"
            ),
        ),
        migrations.AlterField(
            model_name="versionperson",
            name="date_of_birth",
            field=models.DateField(blank=True, null=True, verbose_name="date of birth"),
        ),
        migrations.AlterField(
            model_name="versionperson",
            name="date_of_death",
            field=models.DateField(blank=True, null=True, verbose_name="date of death"),
        ),
        migrations.AlterField(
            model_name="versionperson",
            name="forename",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="forname"
            ),
        ),
        migrations.AlterField(
            model_name="versionperson",
            name="gender",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="gender"
            ),
        ),
        migrations.AlterField(
            model_name="versionperson",
            name="surname",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="surname"
            ),
        ),
        migrations.AlterField(
            model_name="versionplace",
            name="feature_code",
            field=models.CharField(
                blank=True,
                default="",
                help_text='<a href="https://www.geonames.org/export/codes.html">Geonames Feature Code List</a>',
                max_length=16,
                verbose_name="feature code",
            ),
        ),
        migrations.AlterField(
            model_name="versionplace",
            name="label",
            field=models.CharField(
                blank=True, default="", max_length=4096, verbose_name="label"
            ),
        ),
        migrations.AlterField(
            model_name="versionplace",
            name="latitude",
            field=models.FloatField(blank=True, null=True, verbose_name="latitude"),
        ),
        migrations.AlterField(
            model_name="versionplace",
            name="longitude",
            field=models.FloatField(blank=True, null=True, verbose_name="longitude"),
        ),
    ]
