{% extends "apis_core/apis_entities/abstractentity_form.html" %}

{% block relations-include %}
  {% include "relations/list_relations_include_tabs.html" with linkify=True %}
{% endblock relations-include %}
