/* object actions */
.object-view {
    color: var(--object-view-color, rgb(25, 135, 84)) !important;
}

.object-edit {
    color: var(--object-edit-color, rgb(255, 193, 7)) !important;
}

.object-delete {
    color: var(--object-delete-color, rgb(220, 53, 69)) !important;
}

.object-duplicate {
    color: var(--object-duplicate-color, blueviolet);
}

.object-merge {
    color: var(--object-merge-color, dodgerblue);
}

.object-history {
    color: var(--object-history-color, #007bff);
}

.filter-input-selected {
    color: var(--filter-input-selected-color, #228b22);
    font-weight: bold;
}

#snackbar {
    position: fixed;
    bottom: 30px;
    right: 30px;
}

.mytoast {
    z-index: 1;
    animation: fadein 0.5s, fadeout 0.5s 2.6s;
}

@keyframes fadein {
    from {
        opacity: 0;
    }

    to {
        opacity: 1;
    }
}

@keyframes fadeout {
    from {
        opacity: 1;
    }

    to {
        opacity: 0;
    }
}

/* This is copied from the `alert-danger` class from Bootstrap
 * Django uses `error` as a tag in the error messages - we could
 * override this using the MESSAGE_TAGS Django setting, but simply
 * setting the style here means less configuration for the projects.
 */
.alert-error {
    --bs-alert-color: var(--bs-danger-text-emphasis);
    --bs-alert-bg: var(--bs-danger-bg-subtle);
    --bs-alert-border-color: var(--bs-danger-border-subtle);
    --bs-alert-link-color: var(--bs-danger-text-emphasis);
}

/* Lets do the same also for the `debug` tag and reuse the settings
 * from the `alert-secondary` class
 */
.alert-debug {
    --bs-alert-color: var(--bs-secondary-text-emphasis);
    --bs-alert-bg: var(--bs-secondary-bg-subtle);
    --bs-alert-border-color: var(--bs-secondary-border-subtle);
    --bs-alert-link-color: var(--bs-secondary-text-emphasis);
}
