{% load i18n %}
<div class="row">
  <div class="col">
    <input type="{{ widget.type }}"
           name="{{ widget.name }}"
           {% if widget.value != None %}value="{{ widget.value|stringformat:'s' }}"{% endif %}
           {% include "django/forms/widgets/attrs.html" %}>
  </div>
  <div class="col">
    <button class="btn btn-primary"
            type="button"
            onclick='fetchResults("{{ widget.attrs.id }}")'>{% translate "Search" %}</button>
  </div>
</div>
<div class="mt-2"
     id="map"
     {% for name, value in widget.attrs.items %}{% if name|slice:5 == "data-" %}{{ name }}={{ value }}{% endif %}
     {% endfor %}>
</div>
