# Generated by Django 3.1.14 on 2023-03-10 08:04

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_metainfo", "0003_auto_20220218_1530"),
    ]

    operations = [
        migrations.RenameField(
            model_name="rootobject",
            old_name="self_content_type",
            new_name="self_contenttype",
        ),
    ]
